@@ -21,16 +21,16 @@ class LLMInputs(__LLMInputsRequired, total=False):
     model_args: Annotated[str, StepTypeConfig(is_config=True)]
     client_args: Annotated[str, StepTypeConfig(is_config=True)]
     openai_api_key: Annotated[
-        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "google_api_key", "anthropic_api_key"])
+        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "google_api_key", "client_is_gcp", "anthropic_api_key"])
     ]
     anthropic_api_key: Annotated[
-        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "google_api_key", "openai_api_key"])
+        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "google_api_key", "client_is_gcp", "openai_api_key"])
     ]
     patched_api_key: Annotated[
         str,
         StepTypeConfig(
             is_config=True,
-            or_op=["openai_api_key", "google_api_key", "anthropic_api_key"],
+            or_op=["openai_api_key", "google_api_key", "client_is_gcp", "anthropic_api_key"],
             msg=f"""\
 Model API key not found.
 Please login at: "{TOKEN_URL}"
@@ -41,8 +41,12 @@ If you are using a OpenAI API Key, please set `--openai_api_key=<token>`.""",
         ),
     ]
     google_api_key: Annotated[
-        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "openai_api_key", "anthropic_api_key"])
+        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "openai_api_key", "anthropic_api_key", "client_is_gcp"])
     ]
+    client_is_gcp: Annotated[
+        str, StepTypeConfig(is_config=True, or_op=["patched_api_key", "openai_api_key", "anthropic_api_key", "google_api_key"])
+    ]
+    file: Annotated[str, StepTypeConfig(is_path=True)]
     # ExtractModelResponseInputs
     response_partitions: Annotated[Dict[str, List[str]], StepTypeConfig(is_config=True)]
 
@@ -52,5 +56,7 @@ class LLMOutputs(TypedDict):
     prompts: List[Dict]
     # CallLLMOutputs
     openai_responses: List[str]
+    request_tokens: List[int]
+    response_tokens: List[int]
     # ExtractModelResponseOutputs
     extracted_responses: List[Dict[str, str]]
